@@ -49,9 +49,19 @@ void xneur_rem_layout_app(GtkWidget *widget);
 void xneur_add_draw_flag_app(void);
 void xneur_rem_draw_flag_app(GtkWidget *widget);
 
+void xneur_add_abbreviation(void);
+void xneur_rem_abbreviation(GtkWidget *widget);
+
+void xneur_add_action(void);
+void xneur_rem_action(GtkWidget *widget);
+void xneur_edit_action(GtkWidget *treeview);
+
 void xneur_save_preference(GladeXML *gxml);
 void xneur_dontsave_preference(GladeXML *gxml);
 
+void xneur_edit_sound(GtkWidget *treeview);
+void xneur_edit_pixmap(GtkWidget *treeview);
+
 void xneur_start_stop(GtkWidget *widget, struct _tray_icon *tray);
 void xneur_auto_manual(GtkWidget *widget, struct _tray_icon *tray);
 
